summaryrefslogtreecommitdiff
path: root/rts/HsFFI.c
diff options
context:
space:
mode:
Diffstat (limited to 'rts/HsFFI.c')
-rw-r--r--rts/HsFFI.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/rts/HsFFI.c b/rts/HsFFI.c
index 0b9f3f0063..0b3d623302 100644
--- a/rts/HsFFI.c
+++ b/rts/HsFFI.c
@@ -24,8 +24,8 @@ hs_set_argv(int argc, char *argv[])
void
hs_perform_gc(void)
{
- /* Hmmm, the FFI spec is a bit vague, but it seems to imply a major GC... */
- performMajorGC();
+ /* Hmmm, the FFI spec is a bit vague, but it seems to imply a blocking major GC... */
+ performBlockingMajorGC();
}
// Lock the stable pointer table